==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CancelButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelButtonClickEventArgsDescription } from "./CancelButtonClickEventArgsDescription";
/**
 * @hidden
 */
var CancelButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CancelButtonClickEventArgsDescriptionMetadata, _super);
    function CancelButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancelButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (CancelButtonClickEventArgsDescriptionMetadata.a == null) {
            CancelButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancelButtonClickEventArgsDescriptionMetadata.c(CancelButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.j(CancelButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    CancelButtonClickEventArgsDescriptionMetadata.d = function (a) {
        CancelButtonClickEventArgsDescriptionMetadata.b(a);
        a.aa("CancelButtonClickEventArgs", function () { return new CancelButtonClickEventArgsDescription(); });
        a.z("CancelButtonClickEventArgs", CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.$t = markType(CancelButtonClickEventArgsDescriptionMetadata, 'CancelButtonClickEventArgsDescriptionMetadata');
    CancelButtonClickEventArgsDescriptionMetadata.a = null;
    return CancelButtonClickEventArgsDescriptionMetadata;
}(Base));
export { CancelButtonClickEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/CancelButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancelButtonClickEventArgsDescription } from "./CancelButtonClickEventArgsDescription";
/**
 * @hidden
 */
var CancelButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CancelButtonClickEventArgsDescriptionMetadata, _super);
    function CancelButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancelButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (CancelButtonClickEventArgsDescriptionMetadata.a == null) {
            CancelButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancelButtonClickEventArgsDescriptionMetadata.c(CancelButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.k(CancelButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    CancelButtonClickEventArgsDescriptionMetadata.d = function (a) {
        CancelButtonClickEventArgsDescriptionMetadata.b(a);
        a.ac("CancelButtonClickEventArgs", function () { return new CancelButtonClickEventArgsDescription(); });
        a.ab("CancelButtonClickEventArgs", CancelButtonClickEventArgsDescriptionMetadata.a);
    };
    CancelButtonClickEventArgsDescriptionMetadata.$t = markType(CancelButtonClickEventArgsDescriptionMetadata, 'CancelButtonClickEventArgsDescriptionMetadata');
    CancelButtonClickEventArgsDescriptionMetadata.a = null;
    return CancelButtonClickEventArgsDescriptionMetadata;
}(Base));
export { CancelButtonClickEventArgsDescriptionMetadata };
